# Version 2.2.0 was “released” 2020-07-31 based on the version history in
# loguru.hpp, but the tag was never pushed to GitHub. We package a post-release
# snapshot with many bugfixes, CMake support, and Unlicense added as an
# alternative to the original public-domain dedication.
%global commit 4adaa185883e3c04da25913579c451d3c32cfac1
%global snapdate 20230406

# This doesn’t seem to work on EPEL7.
%bcond_with asan

Name:           loguru
Version:        2.2.0
%global so_version 2
Release:        1.%{snapdate}git%(echo '%{commit}' | cut -b -7)%{?dist}
Summary:        A lightweight C++ logging library

License:        LicenseRef-Fedora-Public-Domain OR Unlicense
URL:            https://github.com/emilk/loguru
Source:         %{url}/archive/%{commit}/loguru-%{commit}.tar.gz

# Fix invalid regex in lnav_format_loguru_cpp.json
# https://github.com/emilk/loguru/pull/250
Patch:          %{url}/pull/250.patch

# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}

BuildRequires:  gcc-c++
BuildRequires:  cmake3
# Faster than the "UNIX Makefiles" backend for cmake, with no disadvantages
BuildRequires:  ninja-build

# For tests:
%if %{with asan}
BuildRequires:  libasan
%endif

%description
A lightweight and flexible C++ logging library.


%package devel
Summary:        Development files for loguru

Requires:       loguru%{?_isa} = %{version}-%{release}

%description devel
The loguru-devel package contains libraries and header files for developing
applications that use loguru.


%package lnav
Summary:        Configuration for lnav (Log File Navigator) to support loguru

BuildArch:      noarch

%description lnav
The loguru-lnav package contains configuration for lnav (Log File Navigator) to
support logs produced by loguru.


%package doc
Summary:        Documentation and examples for loguru

BuildArch:      noarch

%description doc
The loguru-doc package contains documentation and examples for developing
applications that use loguru. It does not bring in dependencies for compiling
and running the examples.


%prep
%autosetup -n loguru-%{commit} -p1

# Too strict for downstream packaging
sed -r -i 's/;?-Werror\b//' CMakeLists.txt test/CMakeLists.txt

%if %{without asan}
sed -r -i 's/-fsanitize=address\b//' test/CMakeLists.txt
%endif


%build
# Building examples and tests from the top-level project is not yet supported.
# In docs/index.html, LOGURU_STACKTRACES=1 is documented as the default where
# supported.
%cmake3 \
  -DLOGURU_INSTALL:BOOL=ON \
  -DLOGURU_BUILD_EXAMPLES:BOOL=OFF \
  -DLOGURU_BUILD_TESTS:BOOL=OFF \
  -DLOGURU_STACKTRACES=1 \
  -GNinja
%cmake3_build

pushd test
%cmake3 -GNinja
%cmake3_build
popd


%install
%cmake3_install

# https://docs.lnav.org/en/latest/formats.html#installing-formats
install -d '%{buildroot}%{_sysconfdir}/lnav/formats'
install -p -m 0644 lnav_format_loguru_cpp.json \
    '%{buildroot}%{_sysconfdir}/lnav/formats/loguru_cpp.json'


%check
pushd test
%ctest3
popd


%files
%license LICENSE
%doc README.md
%{_libdir}/libloguru.so.%{so_version}
%{_libdir}/libloguru.so.%{so_version}.*


%files devel
%{_includedir}/loguru/

%{_libdir}/libloguru.so

%{_libdir}/cmake/loguru/
%{_libdir}/pkgconfig/loguru.pc


%files lnav
%license LICENSE
# We must co-own these directories. This subpackage could be installed without
# lnav, and lnav does not create and own them anyway.
%dir %{_sysconfdir}/lnav
%dir %{_sysconfdir}/lnav/formats
%config(noreplace) %{_sysconfdir}/lnav/formats/loguru_cpp.json


%files doc
%license LICENSE
# Basic hand-written HTML documentation
%doc docs/
%doc glog_example/
%doc loguru_cmake_example/
%doc loguru_example/


%changelog
* Mon May 27 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 2.2.0-1.20230406git4adaa18
- Initial package for EPEL7 (close RHBZ#2276336)

